Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/certbot/certbot.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBrad Warren <bmw@eff.org>2016-04-14 20:20:23 +0300
committerBrad Warren <bmw@eff.org>2016-04-14 20:20:23 +0300
commitae6f1c62f11435061c2b30457961561f39afa0c7 (patch)
tree3d284b09106838dd29adf1c288b535d49d0a61e5 /examples
parent214343ed6aa9db12524a45df34f5a26b73abed67 (diff)
Rename misc files
Diffstat (limited to 'examples')
-rw-r--r--examples/cli.ini2
-rwxr-xr-xexamples/generate-csr.sh2
-rw-r--r--examples/plugins/certbot_example_plugins.py (renamed from examples/plugins/letsencrypt_example_plugins.py)8
-rw-r--r--examples/plugins/setup.py12
4 files changed, 12 insertions, 12 deletions
diff --git a/examples/cli.ini b/examples/cli.ini
index f0c993c57..63af3cc49 100644
--- a/examples/cli.ini
+++ b/examples/cli.ini
@@ -1,5 +1,5 @@
# This is an example of the kind of things you can do in a configuration file.
-# All flags used by the client can be configured here. Run Let's Encrypt with
+# All flags used by the client can be configured here. Run Certbot with
# "--help" to learn more about the available options.
# Use a 4096 bit RSA key instead of 2048
diff --git a/examples/generate-csr.sh b/examples/generate-csr.sh
index c4a3af016..55f6c7b9f 100755
--- a/examples/generate-csr.sh
+++ b/examples/generate-csr.sh
@@ -25,4 +25,4 @@ SAN="$domains" openssl req -config "${OPENSSL_CNF:-openssl.cnf}" \
-outform DER
# 512 or 1024 too low for Boulder, 2048 is smallest for tests
-echo "You can now run: letsencrypt auth --csr ${CSR_PATH:-csr.der}"
+echo "You can now run: certbot auth --csr ${CSR_PATH:-csr.der}"
diff --git a/examples/plugins/setup.py b/examples/plugins/setup.py
index 71bb95333..4538e83b8 100644
--- a/examples/plugins/setup.py
+++ b/examples/plugins/setup.py
@@ -2,16 +2,16 @@ from setuptools import setup
setup(
- name='letsencrypt-example-plugins',
- package='letsencrypt_example_plugins.py',
+ name='certbot-example-plugins',
+ package='certbot_example_plugins.py',
install_requires=[
- 'letsencrypt',
+ 'certbot',
'zope.interface',
],
entry_points={
- 'letsencrypt.plugins': [
- 'example_authenticator = letsencrypt_example_plugins:Authenticator',
- 'example_installer = letsencrypt_example_plugins:Installer',
+ 'certbot.plugins': [
+ 'example_authenticator = certbot_example_plugins:Authenticator',
+ 'example_installer = certbot_example_plugins:Installer',
],
},
)
diff --git a/examples/plugins/letsencrypt_example_plugins.py b/examples/plugins/certbot_example_plugins.py
index 5c22ca7ff..9dec2e108 100644
--- a/examples/plugins/letsencrypt_example_plugins.py
+++ b/examples/plugins/certbot_example_plugins.py
@@ -1,12 +1,12 @@
-"""Example Let's Encrypt plugins.
+"""Example Certbot plugins.
-For full examples, see `letsencrypt.plugins`.
+For full examples, see `certbot.plugins`.
"""
import zope.interface
-from letsencrypt import interfaces
-from letsencrypt.plugins import common
+from certbot import interfaces
+from certbot.plugins import common
@zope.interface.implementer(interfaces.IAuthenticator)